/*
 * Copyright (c) 2007, Ryo Ichinose
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *    * Redistributions of source code must retain the above copyright 
 *      notice, this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above copyright 
 *      notice, this list of conditions and the following disclaimer in the 
 *      documentation and/or other materials provided with the distribution.
 *    * Neither the name of the auther nor the 
 *      names of its contributors may be used to endorse or promote products 
 *      derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <avr/interrupt.h>
#include <avr/io.h>
#include <avr/sleep.h>

#include "timer0.h"
#include "util.h"


static void timer0_ov_interrupt(void);


int
main(void)
{
	/* PB0 ԥΤ߽ */
	DDRB |= _BV(DDB0);
	pullup();

	timer0_ov_enable();
	timer0_ov_set_interrupt(timer0_ov_interrupt);
	timer0_set_count(0);

	sei();

	/* (8MHz/256)/256 = 122Hz */
	timer0_start(TIMER0_CK_256);
	
	while (1){
		sleep_mode();
	}

	return 0; /* ٹ򤱤뤿 */
}


static void 
timer0_ov_interrupt(void)
{
	static int count = 0;

	/*
	 * LED ξѹȿ 2Hz (500ms) Ȥ롣
	 * ߼ 122Hz ʤΤ 61˾֤Ѥ롣
	 *
	 * ON-----OFF-----ON-----...
	 *   500ms   500ms  
	 */
	if (++ count != 61) {
		return;
	}

	count = 0;
	PORTB ^= _BV(PB0);
}

/* End of main-ov.c */
